/* $Id$
 *
 * PDFlib client: hello servlet example in Java
 */

import javax.servlet.*;
import javax.servlet.http.*;

import com.pdflib.pdflib;
import com.pdflib.PDFlibException;

public class HelloServlet extends HttpServlet {
    private static final long serialVersionUID = 8003280711027696877L;

    public void service(HttpServletRequest request, HttpServletResponse response)
            throws ServletException {
        int font;
        pdflib p = null;
        byte[] buf;
        ServletOutputStream out;

        try {
            p = new pdflib();
            /*
             * Set errorpoliy to return, this means we must check return
             * values of load_font() etc.
             */
            p.set_option("errorpolicy=return");

            
            // Generate a PDF in memory; insert a file name to create PDF on
            // disk
            if (p.begin_document("", "") == -1) {
                throw new ServletException("Error: " + p.get_apiname() + ": " + p.get_errmsg());
            }

            p.set_info("Creator", "helloServlet.java");
            p.set_info("Author", "Thomas Merz");
            p.set_info("Title", "Hello world (Java/Servlet)!");

            p.begin_page_ext(595, 842, ""); /* start a new page */

            font = p.load_font("Helvetica-Bold", "unicode", "");

            p.setfont(font, 18);

            p.set_text_pos(50, 700);
            p.show("Hello world!");
            p.continue_text("(says Java/Servlet)");
            p.end_page_ext(""); /* close page */

            p.end_document(""); /* close PDF document */

            buf = p.get_buffer();

            response.setContentType("application/pdf");
            response.setContentLength(buf.length);
            response.setHeader("Content-Disposition",
                "inline; filename=hello.pdf");
            
            out = response.getOutputStream();
            out.write(buf);
            out.close();
        }
        catch (PDFlibException e) {
            throw new ServletException("PDFlib exception occurred in "
                    + getClass().getName(), e);
        }
        catch (Exception e) {
            throw new ServletException("Exception occurred in "
                    + getClass().getName(), e);
        }
        finally {
            if (p != null) {
                p.delete(); /* delete the PDFlib object */
            }
        }
    }
}
